"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = __importDefault(require("commander"));
const misc_1 = require("./misc");
const wrapper_1 = require("./wrapper");
const config_1 = require("./config");
const env_1 = require("./env");
exports.execute = () => __awaiter(void 0, void 0, void 0, function* () {
    commander_1.default
        .option('-t, --tag <tag>', 'tag name')
        .option('--token <token>', 'token')
        .option('-b, --branch [branch]', 'branch name')
        .option('-w, --workspace [workspace]', 'working directory name', '.')
        .option('-p, --package [package]', 'package file directory name', process.cwd())
        .option('-e, --env [env]', 'env file name', '.env')
        .option('-n, --dry-run', 'show what would have been pushed')
        .option('--test', 'whether it is test')
        .parse(process.argv);
    const token = commander_1.default.token || env_1.loadTokenFromEnv(commander_1.default.package);
    if (!token) {
        throw new Error('<token> is required.');
    }
    process.env.INPUT_GITHUB_TOKEN = token;
    const helper = misc_1.getGitHelper();
    const config = config_1.getConfig(commander_1.default.package, commander_1.default.test);
    const args = yield misc_1.getContextArgs(helper, commander_1.default.tag, commander_1.default.branch, commander_1.default.package, config);
    env_1.setEnv(config, commander_1.default.workspace);
    if (!wrapper_1.isValidContext(args)) {
        console.log('This is not target tag');
        return;
    }
    yield wrapper_1.prepare(helper, args);
    yield wrapper_1.commit(helper);
    if (!commander_1.default.dryRun) {
        yield wrapper_1.push(helper, args);
    }
});
