"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const github_action_helper_1 = require("@technote-space/github-action-helper");
const command = __importStar(require("@technote-space/release-github-actions/lib/utils/command"));
const misc = __importStar(require("@technote-space/release-github-actions/lib/utils/misc"));
const misc_1 = require("./misc");
exports.isValidContext = (args) => misc.isValidContext(misc_1.getContext(args));
exports.prepareFiles = (logger, com, helper, args, context) => __awaiter(void 0, void 0, void 0, function* () {
    const { buildDir, pushDir } = misc.getParams();
    fs_1.mkdirSync(buildDir, { recursive: true });
    if (args.branch) {
        logger.startProcess('Cloning the remote repo for build...');
        yield helper.checkout(buildDir, context);
    }
    else {
        logger.startProcess('Copying current source to build directory...');
        yield com.execAsync({
            command: 'rsync',
            args: [
                '-ac',
                '-C',
                '--filter=:- .gitignore',
                '--exclude',
                '.git',
                '--exclude',
                '.work',
                '--exclude',
                '.github',
                '--delete',
                './',
                buildDir,
            ],
        });
    }
    logger.startProcess('Running build for release...');
    yield helper.runCommand(buildDir, misc.getBuildCommands(buildDir, pushDir));
});
exports.prepare = (helper, args) => __awaiter(void 0, void 0, void 0, function* () {
    const context = misc_1.getContext(args);
    const { buildDir, pushDir } = misc.getParams();
    const logger = new github_action_helper_1.Logger(command.replaceDirectory);
    const com = new github_action_helper_1.Command(logger);
    yield com.execAsync({ command: `rm -rdf ${buildDir} ${pushDir}` });
    yield command.clone(helper, context);
    yield command.checkBranch(yield helper.getCurrentBranchName(misc.getParams().pushDir), helper);
    yield exports.prepareFiles(logger, com, helper, args, context);
    yield command.createBuildInfoFile(context);
    yield command.copyFiles();
});
exports.commit = (helper) => __awaiter(void 0, void 0, void 0, function* () {
    yield command.config(helper);
    yield command.commit(helper);
});
exports.push = (helper, args) => __awaiter(void 0, void 0, void 0, function* () { return command.push(helper, misc_1.getContext(args)); });
